==> angular.js_1.2.26.orig.tar.gz: angular.js-1.2.26/src/ngLocale/angular-locale_guz-ke.js <==
'use strict';
angular.module("ngLocale", [], ["$provide", function($provide) {
var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "many", OTHER: "other"};
function getDecimals(n) {
  n = n + '';
  var i = n.indexOf('.');
  return (i == -1) ? 0 : n.length - i - 1;
}

function getVF(n, opt_precision) {
  var v = opt_precision;

  if (undefined === v) {
    v = Math.min(getDecimals(n), 3);
  }

  var base = Math.pow(10, v);
  var f = ((n * base) | 0) % base;
  return {v: v, f: f};
}

$provide.value("$locale", {
  "DATETIME_FORMATS": {
    "AMPMS": [
      "Ma/Mo",
      "Mambia/Mog"
    ],
    "DAY": [
      "Chumapiri",
      "Chumatato",
      "Chumaine",
      "Chumatano",
      "Aramisi",
      "Ichuma",
      "Esabato"
    ],
    "MONTH": [
      "Chanuari",
      "Feburari",
      "Machi",
      "Apiriri",
      "Mei",
      "Juni",
      "Chulai",
      "Agosti",
      "Septemba",
      "Okitoba",
      "Nobemba",
      "Disemba"
    ],
    "SHORTDAY": [
      "Cpr",
      "Ctt",
      "Cmn",
      "Cmt",
      "Ars",
      "Icm",
      "Est"
    ],
    "SHORTMONTH": [
      "Can",
      "Feb",
      "Mac",
      "Apr",
      "Mei",
      "Jun",
      "Cul",
      "Agt",
      "Sep",
      "Okt",
      "Nob",
      "Dis"
    ],
    "fullDate": "EEEE, d MMMM y",
    "longDate": "d MMMM y",
    "medium": "d MMM y h:mm:ss a",
    "mediumDate": "d MMM y",
    "mediumTime": "h:mm:ss a",
    "short": "dd/MM/y h:mm a",
    "shortDate": "dd/MM/y",
    "shortTime": "h:mm a"
  },
  "NUMBER_FORMATS": {
    "CURRENCY_SYM": "Ksh",
    "DECIMAL_SEP": ".",
    "GROUP_SEP": ",",
    "PATTERNS": [
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 3,
        "minFrac": 0,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "",
        "posPre": "",
        "posSuf": ""
      },
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 2,
        "minFrac": 2,
        "minInt": 1,
        "negPre": "\u00a4-",
        "negSuf": "",
        "posPre": "\u00a4",
        "posSuf": ""
      }
    ]
  },
  "id": "guz-ke",
  "pluralCat": function (n, opt_precision) {  var i = n | 0;  var vf = getVF(n, opt_precision);  if (i == 1 && vf.v == 0) {    return PLURAL_CATEGORY.ONE;  }  return PLURAL_CATEGORY.OTHER;}
});
}]);

==> angular.js_1.8.2.orig.tar.gz: angular.js-1.8.2/src/ngLocale/angular-locale_guz-ke.js <==
'use strict';
angular.module("ngLocale", [], ["$provide", function($provide) {
var PLURAL_CATEGORY = {ZERO: "zero", ONE: "one", TWO: "two", FEW: "few", MANY: "many", OTHER: "other"};
function getDecimals(n) {
  n = n + '';
  var i = n.indexOf('.');
  return (i == -1) ? 0 : n.length - i - 1;
}

function getVF(n, opt_precision) {
  var v = opt_precision;

  if (undefined === v) {
    v = Math.min(getDecimals(n), 3);
  }

  var base = Math.pow(10, v);
  var f = ((n * base) | 0) % base;
  return {v: v, f: f};
}

$provide.value("$locale", {
  "DATETIME_FORMATS": {
    "AMPMS": [
      "Mambia",
      "Mog"
    ],
    "DAY": [
      "Chumapiri",
      "Chumatato",
      "Chumaine",
      "Chumatano",
      "Aramisi",
      "Ichuma",
      "Esabato"
    ],
    "ERANAMES": [
      "Yeso ataiborwa",
      "Yeso kaiboirwe"
    ],
    "ERAS": [
      "YA",
      "YK"
    ],
    "FIRSTDAYOFWEEK": 6,
    "MONTH": [
      "Chanuari",
      "Feburari",
      "Machi",
      "Apiriri",
      "Mei",
      "Juni",
      "Chulai",
      "Agosti",
      "Septemba",
      "Okitoba",
      "Nobemba",
      "Disemba"
    ],
    "SHORTDAY": [
      "Cpr",
      "Ctt",
      "Cmn",
      "Cmt",
      "Ars",
      "Icm",
      "Est"
    ],
    "SHORTMONTH": [
      "Can",
      "Feb",
      "Mac",
      "Apr",
      "Mei",
      "Jun",
      "Cul",
      "Agt",
      "Sep",
      "Okt",
      "Nob",
      "Dis"
    ],
    "STANDALONEMONTH": [
      "Chanuari",
      "Feburari",
      "Machi",
      "Apiriri",
      "Mei",
      "Juni",
      "Chulai",
      "Agosti",
      "Septemba",
      "Okitoba",
      "Nobemba",
      "Disemba"
    ],
    "WEEKENDRANGE": [
      5,
      6
    ],
    "fullDate": "EEEE, d MMMM y",
    "longDate": "d MMMM y",
    "medium": "d MMM y HH:mm:ss",
    "mediumDate": "d MMM y",
    "mediumTime": "HH:mm:ss",
    "short": "dd/MM/y HH:mm",
    "shortDate": "dd/MM/y",
    "shortTime": "HH:mm"
  },
  "NUMBER_FORMATS": {
    "CURRENCY_SYM": "Ksh",
    "DECIMAL_SEP": ".",
    "GROUP_SEP": ",",
    "PATTERNS": [
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 3,
        "minFrac": 0,
        "minInt": 1,
        "negPre": "-",
        "negSuf": "",
        "posPre": "",
        "posSuf": ""
      },
      {
        "gSize": 3,
        "lgSize": 3,
        "maxFrac": 2,
        "minFrac": 2,
        "minInt": 1,
        "negPre": "-\u00a4",
        "negSuf": "",
        "posPre": "\u00a4",
        "posSuf": ""
      }
    ]
  },
  "id": "guz-ke",
  "localeID": "guz_KE",
  "pluralCat": function(n, opt_precision) {  var i = n | 0;  var vf = getVF(n, opt_precision);  if (i == 1 && vf.v == 0) {    return PLURAL_CATEGORY.ONE;  }  return PLURAL_CATEGORY.OTHER;}
});
}]);
